@@ -2,7 +2,7 @@
 欢迎使用方舟抽卡分析插件
 作者:@kawataku
 时间:2022/07/06
-版本:beta v1.0
+版本:beta v1.0.2
 """
 
 
